% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/squeezeVarRob.R
\name{squeezeVarRob}
\alias{squeezeVarRob}
\title{Robustly Squeeze Sample Variances}
\usage{
squeezeVarRob(var, df, covariate = NULL, robust = FALSE,
  winsor.tail.p = c(0.05, 0.1), min_df = 1)
}
\arguments{
\item{var}{A numeric vector of independent sample variances.}

\item{df}{A numeric vector of degrees of freedom for the sample variances.}

\item{covariate}{If \code{non-NULL}, \code{var.prior} will depend on this numeric covariate. Otherwise, \code{var.prior} is constant.}

\item{robust}{A logical indicating wheter the estimation of \code{df.prior} and \code{var.prior} should be robustified against outlier sample variances. Defaults to \code{FALSE}.}

\item{winsor.tail.p}{A numeric vector of length 1 or 2, giving left and right tail proportions of \code{x} to Winsorize. Used only when \code{robust=TRUE}.}

\item{min_df}{A numeric value indicating the minimal degrees of freedom that will be taken into account for calculating the prior degrees of freedom and prior variance.}

\item{k}{A numeric value indicating that the calculation of the robust squeezed variances should Winsorize at \code{k} standard deviations.}
}
\value{
A list with components:
\code{var.post} A numeric vector of posterior variances.
\code{var.prior} The location of prior distribution. A vector if \code{covariate} is non-\code{NULL}, otherwise a scalar.
\code{df.prior} The degrees of freedom of prior distribution. A vector if \code{robust=TRUE}, otherwise a scalar.
}
\description{
This function squeezes a set of sample variances together by computing empirical Bayes posterior means in a way that is robust against the presence of very small non-integer degrees of freedom values.
}
